Package: DeSciDe
Type: Package
Title: Tool for Unbiased Literature Searching and Gene List Curation
Version: 1.0.3
Authors@R: 
    person("Cameron", "Douglas", email = "camerondouglas@ufl.edu", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-2334-1652"))
Description: Designed for genomic and proteomic data analysis, enabling unbiased PubMed searching, protein interaction network visualization, and comprehensive data summarization. This package aims to help users identify novel targets within their data sets based on protein network interactions and publication precedence of target's association with research context based on literature precedence. Methods in this package are described in detail in: Douglas et al. (2025) <doi:10.1039/D5MO00160A>. Key functionalities of this package also leverage methodologies from previous works, such as:
  - Szklarczyk et al. (2023) <doi:10.1093/nar/gkac1000>
  - Winter (2017) <doi:10.32614/RJ-2017-066>.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: rentrez, ComplexHeatmap, circlize, STRINGdb, data.table,
        igraph, ggplot2, openxlsx, dplyr, tidyr, magrittr, tibble,
        ggrepel
RoxygenNote: 7.3.3
URL: https://github.com/camdouglas/DeSciDe
BugReports: https://github.com/camdouglas/DeSciDe/issues
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, withr
VignetteBuilder: knitr
Config/testthat/edition: 3
Depends: R (>= 4.0.0)
NeedsCompilation: no
Packaged: 2026-04-09 15:31:23 UTC; seathlab
Author: Cameron Douglas [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2334-1652>)
Maintainer: Cameron Douglas <camerondouglas@ufl.edu>
Repository: CRAN
Date/Publication: 2026-04-09 16:00:03 UTC
Built: R 4.4.3; ; 2026-04-09 17:11:42 UTC; unix

# Generated by roxygen2: do not edit by hand

export(combine_summary)
export(descide)
export(plot_clustering)
export(plot_connectivity_precedence)
export(plot_heatmap)
export(plot_string_network)
export(rank_search_results)
export(search_pubmed)
export(search_string_db)
export(single_pubmed_search)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapList)
importFrom(ComplexHeatmap,draw)
importFrom(STRINGdb,STRINGdb)
importFrom(circlize,colorRamp2)
importFrom(data.table,data.table)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grid,gpar)
importFrom(igraph,components)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(magrittr,"%>%")
importFrom(openxlsx,addWorksheet)
importFrom(openxlsx,createWorkbook)
importFrom(openxlsx,saveWorkbook)
importFrom(openxlsx,writeData)
importFrom(rentrez,entrez_search)
importFrom(stats,setNames)
importFrom(tibble,column_to_rownames)
importFrom(tidyr,pivot_wider)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,write.csv)
importFrom(utils,write.table)

# DeSciDe: A Tool for unbiased gene selection by simple visual analysis.

DeSciDe (Deciphering Scientific Discoveries) is an R package designed for genomic and proteomic data analysis, PubMed search, protein interaction network visualization, and comprehensive data summarization.

Features
--------

- Perform PubMed searches for a list of genes and terms.
- Search the STRING database for protein interactions.
- Rank PubMed and STRING search results to identify high confidence and novel hits. 
- Visualize results using heatmaps and network plots.
- Summarize data from multiple sources.

Installation
------------
Before installing the `DeSciDe` package, make sure you have `BiocManager` installed:

    # Install Bioconductor dependencies
    if (!requireNamespace("BiocManager", quietly = TRUE))
        install.packages("BiocManager")
    BiocManager::install("STRINGdb")
    BiocManager::install("ComplexHeatmap")

DeSciDe is available on CRAN, and it can be installed with:

    # Install DeSciDe via CRAN
    install.packages("DeSciDe")

You can install the development version of DeSciDe from GitHub using the `devtools` package:

    # Install devtools if you haven't already
    install.packages("devtools")

    # Install DeSciDe from GitHub
    devtools::install_github("camdouglas/DeSciDe")

Usage
-----

#### Basic Example

Below is a basic example of how to use DeSciDe to analyze a list of genes and terms:

    # Load the package
    library(DeSciDe)

    # Define your list of genes and terms
    genes_list <- c("JUN", "MYC", "HDAC1", "TRIM33")
    terms_list <- c("cancer", "romidepsin")

    # Run the analysis pipeline
    results <- descide(
      genes_list = genes_list, 
      terms_list = terms_list
    )

    # View PubMed search results
    head(results$summary_results)

### Parameters

- `genes_list`: A list of gene IDs.
- `terms_list`: A list of search terms.
- `rank_method`: Method to rank results ("weighted" or "total"). Defaults to "weighted".
- `species`: NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).
- `network_type`: Type of STRING network to use ("full" or "physical"). Defaults to "full".
- `score_threshold`: Minimum score threshold for STRING interactions. Defaults to 400.
- `threshold_percentage`: Percentage threshold for ranking. Defaults to 20%.
- `export`: Logical indicating whether to export the results. Defaults to FALSE.
- `file_directory`: Directory for saving the output files. Defaults to NULL.
- `export_format`: Format for export ("csv", "tsv", "excel"). Defaults to "csv".

### Testing
Due to API rate limits and the potentially long duration of some tests, certain tests are skipped on CRAN using the skip_on_cran() function from the testthat package. These tests are designed to run in local environments and CI/CD pipelines where the environment variable NOT_CRAN is set to "true".

To run all tests locally, set the environment variable as follows:

    NOT_CRAN=true R CMD check

Authors
-------

- **Cameron Douglas** - Initial work - [camerondouglas@ufl.edu](mailto:camerondouglas@ufl.edu)

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 8,
  fig.height = 6
)

## ----setup, include = FALSE---------------------------------------------------
library(DeSciDe)

# Define evaluation flag
eval_flag <- Sys.getenv("NOT_CRAN") == "TRUE"

# Load precomputed results if not in CRAN
if(!eval_flag) {
  load("data/results_default.RData")
  load("data/results_total.RData")
  load("data/threshold_50.RData")
  load("data/threshold_20.RData")
}

## ----error=FALSE--------------------------------------------------------------
# Import genes list and terms list from CSV
genes <- read.csv("genes.csv", header = FALSE)[[1]]
terms <- read.csv("terms.csv", header = FALSE)[[1]]

## -----------------------------------------------------------------------------
genes

## -----------------------------------------------------------------------------
terms

## ----plot_chunk, message=FALSE, warning=FALSE, eval = eval_flag---------------
# results <- descide(genes_list = genes, terms_list = terms)

## ----include = FALSE, eval=!eval_flag-----------------------------------------
# Load precomputed results
results <- results_default

## ----fig.width=8, fig.height=6, echo = FALSE----------------------------------
head(results$summary_results)

## ----fig.width=8, fig.height=6, echo = FALSE----------------------------------
plot_heatmap(results$pubmed_results)

## ----fig.width=8, fig.height=6, echo = FALSE----------------------------------
knitr::include_graphics("data/Network_full.pdf")

## ----fig.width=8, fig.height=6, echo = FALSE----------------------------------
plot_clustering(results$string_results)

## ----fig.width=8, fig.height=6, echo = FALSE----------------------------------
plot_connectivity_precedence(results$summary_results)

## ----message=FALSE, fig.width=8, fig.height=6, eval = eval_flag---------------
# results_total <- descide(genes_list = genes, terms_list = terms, rank_method = "total")

## ----include = FALSE, eval=!eval_flag-----------------------------------------
# Load precomputed results for rank_method = "total"
results_total <- results_total

## -----------------------------------------------------------------------------
head(results$summary_results)

## -----------------------------------------------------------------------------
head(results_total$summary_results)

## ----eval=FALSE, fig.width=8, fig.height=6------------------------------------
# # Change species to mus musculus for STRING search.
# descide(genes_list = genes, terms_list = terms, species = 10090)

## ----eval=FALSE, fig.width=8, fig.height=6------------------------------------
# # Change STRING score threshold to 600.
# descide(genes_list = genes, terms_list = terms, score_threshold = 600)

## ----eval=FALSE, fig.width=8, fig.height=6------------------------------------
# # Change STRING network type to only include physical interactions.
# descide(genes_list = genes, terms_list = terms, network_type = "physical")

## ----full_string_chunk, warning=FALSE, fig.width=8, fig.height=6, eval = eval_flag----
# # Run STRING search and display network with full network.
# full_string <- search_string_db(genes_list = genes, network_type = "full")
# plot_string_network(full_string$string_db, full_string$string_ids)

## ----warning=FALSE, fig.width=8, fig.height=6, echo=FALSE, eval=!eval_flag----
knitr::include_graphics("data/Network_full.pdf")

## ----physical_string_chunk, warning=FALSE, fig.width=8, fig.height=6, eval = eval_flag----
# # Run STRING search and display network with physical network.
# physical_string <- search_string_db(genes_list = genes, network_type = "physical")
# plot_string_network(physical_string$string_db, physical_string$string_ids)

## ----warning=FALSE, fig.width=8, fig.height=6, echo=FALSE, eval=!eval_flag----
knitr::include_graphics("data/Network_physical.pdf")

## ----eval=FALSE, fig.width=8, fig.height=6------------------------------------
# # Command to adjust threshold_percentage for full descide pipeline.
# results <- descide(genes_list = genes, terms_list = terms, threshold_percentage = 50)

## ----fig.width=8, fig.height=6------------------------------------------------
# Calculate and plot threshold of 20%.
threshold_20 <- combine_summary(pubmed_search_results = results$pubmed_results, string_results = results$string_results, threshold_percentage = 20)
plot_connectivity_precedence(combined_summary = threshold_20)

## ----fig.width=8, fig.height=6, include=FALSE, eval=!eval_flag----------------
# Load precomputed results for threshold 20%
threshold_20 <- threshold_20
plot_connectivity_precedence(combined_summary = threshold_20)

## ----fig.width=8, fig.height=6------------------------------------------------
# Calculate and plot threshold of 50%.
threshold_50 <- combine_summary(pubmed_search_results = results$pubmed_results, string_results = results$string_results, threshold_percentage = 50)
plot_connectivity_precedence(combined_summary = threshold_50)

## ----fig.width=8, fig.height=6, include=FALSE, eval=!eval_flag----------------
# Load precomputed results for threshold 50%
threshold_50 <- threshold_50
plot_connectivity_precedence(combined_summary = threshold_50)

## -----------------------------------------------------------------------------
head(threshold_20)
head(threshold_50)

## ----eval=FALSE,fig.width=8, fig.height=6-------------------------------------
# # Code to run DeSciDe and export all plots and tables to desired directory.
# descide(genes_list = genes, terms_list = terms, export = TRUE, file_directory = "your/desired/directory", export_format = "excel")

## ----eval=FALSE---------------------------------------------------------------
# descide(
#   genes_list,
#   terms_list,
#   rank_method = "weighted",
#   species = 9606,
#   network_type = "full",
#   score_threshold = 400,
#   threshold_percentage = 20,
#   export = FALSE,
#   file_directory = NULL,
#   export_format = "csv"
# )

## ----eval=FALSE---------------------------------------------------------------
# search_pubmed(genes_list, terms_list, rank_method = "weighted")

## ----eval=FALSE---------------------------------------------------------------
# plot_heatmap(pubmed_search_results, file_directory = NULL, export = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# search_string_db(
#   genes_list,
#   species = 9606,
#   network_type = "full",
#   score_threshold = 400
# )

## ----eval=FALSE---------------------------------------------------------------
# plot_string_network(
#   string_db,
#   string_ids,
#   file_directory = NULL,
#   export = FALSE
# )

## ----eval=FALSE---------------------------------------------------------------
# plot_clustering(string_results, file_directory = NULL, export = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# combine_summary(
#   pubmed_search_results,
#   string_results,
#   file_directory = NULL,
#   export_format = "csv",
#   export = FALSE,
#   threshold_percentage = 20
# )

## ----eval=FALSE---------------------------------------------------------------
# plot_connectivity_precedence(
#   combined_summary,
#   file_directory = NULL,
#   export = FALSE
# )

#' @importFrom ComplexHeatmap Heatmap HeatmapList draw
#' @importFrom circlize colorRamp2
#' @importFrom grid gpar
#' @importFrom grDevices dev.off png
#' @importFrom tibble column_to_rownames
NULL

# Declare global variables
utils::globalVariables(c(
  "Gene", "PubMed_Rank", "Connectivity_Rank", "Category", "Gene_Symbol", "Degree",
  "Clustering_Coefficient_Percent", "Total", "Term", "Count", "gene", "."
))

#' Plot Heatmap
#'
#' Create and optionally save a heatmap of the PubMed search results.
#'
#' @param pubmed_search_results A data frame containing raw search results with genes and terms.
#' @param file_directory Directory for saving the output plot. Defaults to NULL.
#' @param export Logical indicating whether to export the plot. Defaults to FALSE.
#' @return Invisibly returns a \code{HeatmapList} object.
#' @examples
#' # Example data frame
#' data <- data.frame(Gene = c("Gene1", "Gene2"),
#'                    Term1 = c(10, 20),
#'                    Term2 = c(5, 15),
#'                    Total = c(15, 35),
#'                    PubMed_Rank = c(1, 2))
#' plot_heatmap(data, file_directory = tempdir(), export = FALSE)
#' @export
plot_heatmap <- function(pubmed_search_results, file_directory = NULL, export = FALSE) {
  if (nrow(pubmed_search_results) == 0) {
    warning("No data available to plot heatmap.")
    return(invisible(NULL))
  }

  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  # Prepare heatmap data
  heatmap_data <- pubmed_search_results %>%
    select(-Total, -PubMed_Rank) %>%
    column_to_rownames("Gene")

  if (nrow(heatmap_data) < 2) {
    warning("Not enough data to create a meaningful heatmap.")
    return(invisible(NULL))
  }

  # Convert data frame to matrix
  heatmap_data <- as.matrix(heatmap_data)

  if (all(is.na(heatmap_data))) {
    warning("No valid data points in heatmap data.")
    return(invisible(NULL))
  }

  column_max <- apply(heatmap_data, 2, max, na.rm = TRUE)

  if (all(column_max == 0)) {
    warning("heatmap_data has zero values in each column; unable to create meaningful color scale.")
    return(invisible(NULL))
  }

  color_scales <- lapply(seq_len(ncol(heatmap_data)), function(i) {
    colorRamp2(c(0, column_max[i]), c("white", "navy"))
  })

  heatmap_list <- HeatmapList()
  for (i in seq_len(ncol(heatmap_data))) {
    heatmap_list <- heatmap_list +
      Heatmap(heatmap_data[, i, drop = FALSE],
              col = color_scales[[i]],
              name = colnames(heatmap_data)[i],
              cluster_rows = FALSE,
              cluster_columns = FALSE,
              show_row_names = TRUE,
              show_column_names = TRUE,
              column_names_rot = 0,
              row_names_side = "left",
              column_title_gp = gpar(fontface = "bold"),
              column_names_gp = gpar(fontface = "bold", just = "center"))
  }

  if (export && !is.null(file_directory)) {
    output_filename <- paste(formatted_date, "PubMed_Heatmap.png", sep = "_")
    full_output_path <- file.path(file_directory, output_filename)
    png(filename = full_output_path, width = 800, height = 1200)
    draw(heatmap_list, column_title = "PubMed Search Results", column_title_gp = gpar(fontface = "bold", fontsize = 20))
    dev.off()
    message("Heatmap plot exported to:", full_output_path)
  } else {
    draw(heatmap_list, column_title = "PubMed Search Results", column_title_gp = gpar(fontface = "bold", fontsize = 20))
  }

  return(invisible(heatmap_list))
}

#' @importFrom rentrez entrez_search
#' @importFrom dplyr mutate select arrange desc all_of row_number group_by summarise left_join across
#' @importFrom tidyr pivot_wider
#' @importFrom utils write.csv write.table
#' @importFrom magrittr %>%
NULL

# Declare global variables
utils::globalVariables(c(
  "Gene", "PubMed_Rank", "Connectivity_Rank", "Category", "Gene_Symbol", "Degree",
  "Clustering_Coefficient_Percent", "Total", "Term", "Count", "gene", "."
))

#' Search PubMed
#'
#' Perform a PubMed search for a given gene and term.
#'
#' @param gene A character string representing the gene symbol.
#' @param term A character string representing the search term.
#' @return An integer representing the number of PubMed articles found from the search query in PubMed.
#' @examples
#' # Perform a PubMed search for gene 'TP53' with term 'cancer'
#' result <- single_pubmed_search("TP53", "cancer")
#' print(result)
#' @export
single_pubmed_search <- function(gene, term) {
  query <- paste0('"', gene, "[TIAB]\"", " AND ", '"', term, "[TIAB]\"")
  single_search_results <- entrez_search(db = "pubmed", term = query)
  return(single_search_results$count)
}

#' Rank Search Results
#'
#' Rank search results based on a chosen method.
#'
#' @param data A data frame containing search results.
#' @param terms_list A list of search terms.
#' @param rank_method The method to rank pubmed results, either "weighted" or "total". Weighted ranks results based on order of terms inputted. Total ranks results on total sum of publications across all search term combinations. Defaults to "weighted".
#' @return A data frame with ranked search results, which includes the genes and their corresponding ranks based on the search method.
#' @examples
#' # Example data frame
#' data <- data.frame(Gene = c("Gene1", "Gene2"),
#'                    Term1 = c(10, 20),
#'                    Term2 = c(5, 15))
#' terms_list <- c("Term1", "Term2")
#' ranked_results <- rank_search_results(data, terms_list, rank_method = "weighted")
#' print(ranked_results)
#' @export
rank_search_results <- function(data, terms_list, rank_method = "weighted") {
  if (rank_method == "weighted") {
    data <- data %>%
      mutate(Total = rowSums(select(., -Gene))) %>%
      select(Gene, all_of(terms_list), Total) %>%
      arrange(desc(across(all_of(terms_list)))) %>%
      mutate(PubMed_Rank = row_number())
  } else if (rank_method == "total") {
    data <- data %>%
      mutate(Total = rowSums(select(., -Gene))) %>%
      arrange(desc(Total)) %>%
      mutate(PubMed_Rank = row_number())
  } else {
    stop("Invalid rank_method. Choose either 'weighted' or 'total'.")
  }
  return(data)
}

#' Search PubMed with Multiple Genes and Terms
#'
#' Perform a PubMed search for multiple genes and terms.
#'
#' @param genes_list A list of gene IDs.
#' @param terms_list A list of search terms.
#' @param rank_method The method to rank results, either "weighted" or "total". Defaults to "weighted".
#' @param verbose Logical flag indicating whether to display messages. Default is TRUE.
#' @return A data frame with search results, including genes, terms, and their corresponding publication counts and ranks.
#' @examples
#' genes <- c("TP53", "BRCA1")
#' terms <- c("cancer", "tumor")
#' search_results <- search_pubmed(genes, terms, rank_method = "weighted", verbose = FALSE)
#' print(search_results)
#' @export
search_pubmed <- function(genes_list, terms_list, rank_method = "weighted", verbose = TRUE) {
  single_search_results <- data.frame(Gene = character(), Term = character(), Count = integer())

  for (gene in genes_list) {
    for (term in terms_list) {
      if (verbose) {
        message(paste("Searching PubMed for gene:", gene, "and term:", term))
      }
      count <- single_pubmed_search(gene, term)
      single_search_results <- rbind(single_search_results, data.frame(Gene = gene, Term = term, Count = count))
    }
  }

  aggregated_results <- single_search_results %>%
    group_by(Gene, Term) %>%
    summarise(Count = sum(Count), .groups = 'drop')

  pubmed_search_results <- aggregated_results %>%
    pivot_wider(names_from = Term, values_from = Count, values_fill = list(Count = 0))

  pubmed_search_results <- rank_search_results(pubmed_search_results, terms_list, rank_method)

  return(pubmed_search_results)
}

#' @importFrom STRINGdb STRINGdb
#' @importFrom data.table data.table
#' @importFrom igraph graph_from_adjacency_matrix components
#' @importFrom dplyr group_by mutate arrange desc slice
#' @importFrom stats setNames
#' @importFrom grDevices dev.off pdf
#' @importFrom magrittr %>%
#' @importFrom utils head str
NULL

# Declare global variables
utils::globalVariables(c(
  "Gene", "PubMed_Rank", "Connectivity_Rank", "Category", "Gene_Symbol", "Degree",
  "Clustering_Coefficient_Percent", "Total", "Term", "Count", "gene", "."
))

#' Search STRING Database
#'
#' Search the STRING database for protein interactions.
#'
#' @param genes_list A list of gene IDs.
#' @param species The NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).
#' @param network_type The type of network to use, either "full" or "physical". Defaults to "full".
#' @param score_threshold The minimum score threshold for string interactions. Defaults to 400.
#' @return A list containing the following elements:
#'   \describe{
#'     \item{string_results}{A data frame with STRING interaction metrics.}
#'     \item{string_db}{The STRINGdb object used.}
#'     \item{string_ids}{The STRING IDs for the input genes.}
#'   }
#' @examples
#' \dontrun{
#' library(STRINGdb)
#' genes <- c("TP53", "BRCA1")
#' results <- search_string_db(genes)
#' print(results)
#' }
#' @export
search_string_db <- function(genes_list, species = 9606, network_type = "full", score_threshold = 400) {
  if (length(genes_list) == 0) {
    warning("No genes provided for STRING database search.")
    return(list(string_results = data.frame(), string_db = NULL, string_ids = NULL))
  }

  string_db <- STRINGdb$new(species = species, score_threshold = score_threshold, input_directory = "", network_type = network_type, version = "12.0")

  mapped_genes <- string_db$map(data.frame(gene = genes_list), "gene")
  if (nrow(mapped_genes) == 0) {
    warning("No valid genes found in STRING database for provided genes_list.")
    return(list(string_results = data.frame(), string_db = string_db, string_ids = NULL))
  }

  unique_mapped_genes <- mapped_genes %>% group_by(gene) %>% slice(1)
  string_ids <- unique_mapped_genes$STRING_id

  interactions <- string_db$get_interactions(string_ids)
  interaction_pairs <- data.table(proteinA = pmin(interactions$from, interactions$to), proteinB = pmax(interactions$from, interactions$to))
  interaction_pairs <- unique(interaction_pairs)
  interaction_pairs <- interaction_pairs[interaction_pairs$proteinA != interaction_pairs$proteinB, ]

  if (nrow(interaction_pairs) == 0) {
    warning("No interactions found for the provided genes in STRING database.")
    return(list(string_results = data.frame(), string_db = string_db, string_ids = string_ids))
  }

  nodes <- unique(c(interaction_pairs$proteinA, interaction_pairs$proteinB, string_ids))
  adjacency_matrix <- matrix(0, nrow = length(nodes), ncol = length(nodes), dimnames = list(nodes, nodes))

  for (i in 1:nrow(interaction_pairs)) {
    adjacency_matrix[interaction_pairs$proteinA[i], interaction_pairs$proteinB[i]] <- 1
    adjacency_matrix[interaction_pairs$proteinB[i], interaction_pairs$proteinA[i]] <- 1
  }

  degree <- rowSums(adjacency_matrix)
  clustering_coefficients <- numeric(length(nodes))
  for (i in seq_along(nodes)) {
    neighborhood <- which(adjacency_matrix[i, ] == 1)
    k <- length(neighborhood)
    if (k >= 2) {
      subgraph <- adjacency_matrix[neighborhood, neighborhood]
      triangles <- sum(subgraph) / 2
      clustering_coefficients[i] <- 2 * triangles / (k * (k -1))
    }
  }

  graph_obj <- graph_from_adjacency_matrix(adjacency_matrix, mode = "undirected")
  components <- components(graph_obj)

  gene_symbol_lookup <- setNames(unique_mapped_genes$gene, unique_mapped_genes$STRING_id)
  nodes_symbols <- sapply(nodes, function(node) {
    if(node %in% names(gene_symbol_lookup)) {
      gene_symbol_lookup[node]
    } else {
      # Return the STRING ID instead of NA
      node
    }
  })

  string_results <- data.frame(
    Gene_Symbol = nodes_symbols,
    Degree = degree,
    Clustering_Coefficient_Percent = clustering_coefficients * 100,
    Clustering_Coefficient_Fraction = sapply(1:length(nodes), function(i) {
      k <- degree[i]
      if (k < 2) return("0 / 0")
      else {
        max_possible_edges <- k * (k - 1) / 2
        actual_edges <- clustering_coefficients[i] * max_possible_edges
        return(paste(round(actual_edges), "/", max_possible_edges, sep = ""))
      }
    }),
    Connected_Component_id = as.numeric(components$membership),
    Nodes_in_Connected_Component = as.numeric(components$csize[components$membership]),
    total_number_of_connected_components = components$no,
    row.names = NULL  # Add this line
  )

  string_results <- string_results %>%
    arrange(desc(Degree), desc(Clustering_Coefficient_Percent)) %>%
    mutate(Connectivity_Rank = row_number())

  return(list(string_results = string_results, string_db = string_db, string_ids = string_ids))
}

#' Plot STRING Network
#'
#' Plot STRING network interactions using STRINGdb.
#'
#' @param string_db A STRINGdb object.
#' @param string_ids A list of STRING IDs.
#' @param file_directory Directory for saving the output plot. Defaults to NULL.
#' @param export Logical indicating whether to export the plot. Defaults to FALSE.
#' @return Invisibly returns NULL.
#' @examples
#' \dontrun{
#' library(STRINGdb)
#' string_db <- STRINGdb$new(species = 9606)
#' string_ids <- c("9606.ENSP00000269305", "9606.ENSP00000357940")
#' plot_string_network(string_db, string_ids, file_directory = tempdir(), export = FALSE)
#' }
#' @export
plot_string_network <- function(string_db, string_ids, file_directory = NULL, export = FALSE) {
  if (is.null(string_db) || is.null(string_ids) || length(string_ids) == 0) {
    warning("No valid STRING data available to plot network.")
    return(invisible(NULL))
  }

  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  if (export && !is.null(file_directory)) {
    network_output_filename <- paste(formatted_date, "STRINGdb_Network.pdf", sep = "_")
    full_network_output_path <- file.path(file_directory, network_output_filename)
    pdf(file = full_network_output_path, width = 12, height = 12)
    string_db$plot_network(string_ids)
    dev.off()
    message(paste("Network plot exported to:", full_network_output_path))
  } else {
    string_db$plot_network(string_ids)
  }

  return(invisible(NULL))
}

#' Plot STRING Interactions
#'
#' Plot STRING interactions degree vs. clustering.
#'
#' @param string_results Data frame with STRING metrics.
#' @param file_directory Directory for saving the output plot. Defaults to NULL.
#' @param export Logical indicating whether to export the plot. Defaults to FALSE.
#' @return Invisibly returns the ggplot object.
#' @examples
#' # Example data frame
#' string_results <- data.frame(Degree = c(10, 5), Clustering_Coefficient_Percent = c(20, 10))
#' plot_clustering(string_results, file_directory = tempdir(), export = FALSE)
#' @export
plot_clustering <- function(string_results, file_directory = NULL, export = FALSE) {
  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  if (is.null(string_results) || !all(c("Degree", "Clustering_Coefficient_Percent") %in% names(string_results))) {
    warning("Essential columns missing in string_results")
    return(invisible(NULL))
  }

  if (nrow(string_results) == 0) {
    warning("No data available for clustering plot.")
    return(invisible(NULL))
  }

  string_results$Degree <- as.numeric(string_results$Degree)
  string_results$Clustering_Coefficient_Percent <- as.numeric(string_results$Clustering_Coefficient_Percent)

  plot <- ggplot(string_results, aes(x = Degree, y = Clustering_Coefficient_Percent)) +
    geom_point(color = "black", alpha = 1) +
    theme_minimal() +
    labs(title = "Connectivity of Query",
         x = "Degree (Number of Neighbors)",
         y = "Clustering Coefficient (%)") +
    theme(
      plot.title = element_text(hjust = 0.5, size = 14, face = "bold"),
      axis.title.x = element_text(size = 12),
      axis.title.y = element_text(size = 12),
      axis.text = element_text(size = 10),
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      axis.ticks = element_line(color = "black"),
      axis.line = element_blank(),
      panel.border = element_rect(color = "black", fill = NA, linewidth = 1)
    )

  if (export && !is.null(file_directory)) {
    scatter_output_filename <- paste(formatted_date, "Degree_vs_ClusteringCoefficient.png", sep = "_")
    full_scatter_output_path <- file.path(file_directory, scatter_output_filename)
    png(filename = full_scatter_output_path, width = 1000, height = 800, res = 150)
    print(plot)
    dev.off()
    message(paste("Scatter plot file path:", full_scatter_output_path))
  } else {
    print(plot)
  }

  return(invisible(plot))
}

library(testthat)
library(DeSciDe)

test_that("descide function handles minimal input", {
  skip_on_cran()  # Skipping this test on CRAN

  # Capture messages and warnings
  captured_messages_warnings <- capture.output({
    suppressWarnings({
      results <- descide(
        genes_list = c("MYC"),
        terms_list = c("cancer"),
        export = FALSE
      )
    })
  }, type = "message")

  expect_type(results, "list")
  expect_s3_class(results$pubmed_results, "data.frame")
  expect_s3_class(results$string_results, "data.frame")
  expect_gt(nrow(results$pubmed_results), 0)
  expect_equal(nrow(results$string_results), 0)

  expect_warning(res <- plot_heatmap(results$pubmed_results), "Not enough data to create a meaningful heatmap.")
  expect_null(res)

  expect_warning(res <- plot_string_network(results$string_db, results$string_ids), "No valid STRING data available to plot network.")
  expect_null(res)

  expect_warning(res <- plot_clustering(results$string_results), "Essential columns missing in string_results")
  expect_null(res)

  expect_warning(res <- plot_connectivity_precedence(results$summary_results), "Not enough data to plot genes.")
  expect_null(res)
})

test_that("descide function handles empty input", {
  skip_on_cran()  # Skipping this test on CRAN

  # Capture messages and warnings
  captured_messages_warnings <- capture.output({
    suppressWarnings({
      results <- descide(
        genes_list = character(0),
        terms_list = character(0),
        export = FALSE
      )
    })
  }, type = "message")

  expect_type(results, "list")
  expect_s3_class(results$pubmed_results, "data.frame")
  expect_s3_class(results$string_results, "data.frame")
  expect_equal(nrow(results$pubmed_results), 0)
  expect_equal(nrow(results$string_results), 0)
  expect_equal(nrow(results$summary_results), 0)

  expect_warning(res <- plot_heatmap(results$pubmed_results), "No data available to plot heatmap.")
  expect_null(res)

  expect_warning(res <- plot_string_network(results$string_db, results$string_ids), "No valid STRING data available to plot network.")
  expect_null(res)

  expect_warning(res <- plot_clustering(results$string_results), "Essential columns missing in string_results")
  expect_null(res)

  expect_warning(res <- plot_connectivity_precedence(results$summary_results), "Not enough data to plot genes.")
  expect_null(res)
})

# Load necessary packages
library(testthat)
library(DeSciDe)
library(withr)

test_that("descide function works correctly without export", {
  skip_on_cran()  # Skipping this test on CRAN

  # Define the genes and terms lists
  genes_list <- c("JUN", "MYC", "HDAC1", "TRIM33")
  terms_list <- c("cancer", "romidepsin")

  # Capture messages and warnings to check function execution
  f_capture_output <- capture.output({
    f_capture_message <- capture.output({
      results <- suppressWarnings({
        descide(
          genes_list = genes_list,
          terms_list = terms_list,
          export = FALSE
        )
      })
    }, type = "message")
  })

  # Check that results is a list
  expect_type(results, "list")

  # Check that pubmed_results, string_results, and summary_results are data frames
  expect_s3_class(results$pubmed_results, "data.frame")
  expect_s3_class(results$string_results, "data.frame")
  expect_s3_class(results$summary_results, "data.frame")

  # Ensure pubmed_results has rows
  expect_gt(nrow(results$pubmed_results), 0)

  # Ensure string_results has rows
  expect_gt(nrow(results$string_results), 0)

  # Ensure summary_results has rows
  expect_gt(nrow(results$summary_results), 0)

  # Assert that certain output messages were printed during the plot functions
  expect_true(any(grepl("Starting analysis pipeline", f_capture_message)))
  expect_true(any(grepl("Performing PubMed search", f_capture_message)))
  expect_true(any(grepl("Plotting heatmap of PubMed search results", f_capture_message)))
  expect_true(any(grepl("Performing STRING database search", f_capture_message)))
  expect_true(any(grepl("Plotting STRING network interactions", f_capture_message)))
  expect_true(any(grepl("Combining summaries", f_capture_message)))
  expect_true(any(grepl("Plotting clustering coefficient", f_capture_message)))
  expect_true(any(grepl("Categorizing and plotting genes", f_capture_message)))
  expect_true(any(grepl("FINISHED: Analysis pipeline completed", f_capture_message)))
})

test_that("plotting functions execute without error", {
  skip_on_cran()  # Skipping this test on CRAN

  # Define genes and terms lists
  genes_list <- c("JUN", "MYC", "HDAC1", "TRIM33")
  terms_list <- c("cancer", "romidepsin")

  # Capture messages and warnings to check function execution
  f_capture_output <- capture.output({
    results <- suppressWarnings({
      descide(
        genes_list = genes_list,
        terms_list = terms_list,
        export = FALSE
      )
    })
  }, type = "message")

  # Ensure plot functions execute without error
  expect_no_error(plot_heatmap(results$pubmed_results))
  expect_no_error({
    if (!is.null(results$string_ids) && length(results$string_ids) > 0){
      plot_string_network(results$string_db, results$string_ids)
    }
  })
  expect_no_error(plot_clustering(results$string_results))
  expect_no_error(plot_connectivity_precedence(results$summary_results))
})

#' @importFrom dplyr left_join mutate arrange desc row_number select filter case_when all_of across
#' @importFrom ggplot2 aes geom_point geom_text scale_color_manual theme_minimal labs theme element_text element_blank element_line element_rect ggplot
#' @importFrom ggrepel geom_text_repel
#' @importFrom grDevices dev.off png
#' @importFrom stats setNames
#' @importFrom utils write.csv write.table
#' @importFrom magrittr %>%
#' @importFrom openxlsx createWorkbook addWorksheet writeData saveWorkbook
NULL

# Declare global variables
utils::globalVariables(c(
  "Gene", "PubMed_Rank", "Connectivity_Rank", "Category", "Gene_Symbol", "Degree",
  "Clustering_Coefficient_Percent", "Total", "Term", "Count", "gene", "."
))

#' Combine PubMed and STRING Metrics
#'
#' Combine PubMed search summary and STRING gene metrics.
#'
#' @param pubmed_search_results Data frame with PubMed search results.
#' @param string_results Data frame with STRING metrics.
#' @param file_directory Directory for saving the output summary. Defaults to NULL.
#' @param export_format Format for export, either "csv", "tsv", or "excel".
#' @param export Logical indicating whether to export the summary. Defaults to FALSE.
#' @param threshold_percentage Percentage threshold for ranking (default is 20%).
#' @return A data frame with combined summary including connectivity, precedence, and category.
#' @examples
#' pubmed_data <- data.frame(Gene = c("Gene1", "Gene2"), PubMed_Rank = c(1, 2))
#' string_data <- data.frame(Gene = c("Gene1", "Gene2"), Connectivity_Rank = c(2, 1))
#' combined <- combine_summary(pubmed_data, string_data, export = FALSE)
#' print(combined)
#' @export
combine_summary <- function(pubmed_search_results, string_results, file_directory = NULL, export_format = "csv", export = FALSE, threshold_percentage = 20) {
  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  if (nrow(pubmed_search_results) == 0 && nrow(string_results) == 0) {
    message("Both PubMed and STRING results are empty.")
    return(data.frame())
  }

  if (nrow(pubmed_search_results) > 0) {
    colnames(pubmed_search_results)[1] <- "Gene"
  }

  if (nrow(string_results) > 0) {
    colnames(string_results)[1] <- "Gene"
  }

  if (nrow(pubmed_search_results) == 0) {
    message("PubMed results are empty, returning empty data frame.")
    return(data.frame())
  }

  if (nrow(string_results) == 0) {
    message("STRING results are empty, returning empty data frame.")
    return(data.frame())
  }

  combined_summary <- pubmed_search_results %>%
    left_join(string_results, by = "Gene")

  if (nrow(combined_summary) == 0) {
    message("No matching genes found, returning empty data frame.")
    return(combined_summary)
  }

  top_threshold <- ceiling(nrow(combined_summary) * (threshold_percentage / 100))
  bottom_threshold <- nrow(combined_summary) - top_threshold + 1

  combined_summary <- combined_summary %>%
    mutate(Category = case_when(
      Connectivity_Rank <= top_threshold & PubMed_Rank <= top_threshold ~ "High Connectivity - High Precedence",
      Connectivity_Rank <= top_threshold & PubMed_Rank >= bottom_threshold ~ "High Connectivity - Low Precedence",
      TRUE ~ "Other"
    ))

  if (export && !is.null(file_directory)) {
    if (export_format == "csv") {
      summary_filename <- paste(formatted_date, "Combined_Summary.csv", sep = "_")
      full_summary_path <- file.path(file_directory, summary_filename)
      write.csv(combined_summary, file = full_summary_path, row.names = FALSE)
    } else if (export_format == "tsv") {
      summary_filename <- paste(formatted_date, "Combined_Summary.tsv", sep = "_")
      full_summary_path <- file.path(file_directory, summary_filename)
      write.table(combined_summary, file = full_summary_path, sep = "\t", row.names = FALSE, quote = FALSE)
    } else if (export_format == "excel") {
      summary_filename <- paste(formatted_date, "Combined_Summary.xlsx", sep = "_")
      full_summary_path <- file.path(file_directory, summary_filename)
      wb <- openxlsx::createWorkbook()
      openxlsx::addWorksheet(wb, "Summary")
      openxlsx::writeData(wb, "Summary", combined_summary)
      openxlsx::saveWorkbook(wb, full_summary_path, overwrite = TRUE)
    } else {
      stop("Invalid export format. Choose 'csv', 'tsv', or 'excel'.")
    }
    message(paste("Summary table exported to:", full_summary_path))
  }

  return(invisible(combined_summary))
}

#' Plot Connectivity vs. Precedence
#'
#' Create a scatter plot of Connectivity Rank vs. PubMed Rank.
#'
#' @param combined_summary Data frame with combined summary including categories.
#' @param file_directory Directory for saving the output plot. Defaults to NULL.
#' @param export Logical indicating whether to export the plot. Defaults to FALSE.
#' @return Invisibly returns a ggplot object.
#' @examples
#' combined_data <- data.frame(Gene = c("Gene1", "Gene2"), Connectivity_Rank = c(1, 2),
#'                             PubMed_Rank = c(2, 1),
#'                             Category = c("High Connectivity - High Precedence", "Other"))
#' plot_connectivity_precedence(combined_data, export = FALSE)
#' @export
plot_connectivity_precedence <- function(combined_summary, file_directory = NULL, export = FALSE) {
  if (nrow(combined_summary) == 0) {
    warning("Not enough data to plot genes.")
    return(invisible(NULL))
  }

  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  plot <- ggplot(combined_summary, aes(x = Connectivity_Rank, y = PubMed_Rank, color = Category)) +
    geom_point(alpha = 1) +
    scale_color_manual(values = c("High Connectivity - High Precedence" = "navy", "High Connectivity - Low Precedence" = "red", "Other" = "black")) +
    geom_text_repel(data = combined_summary %>% filter(Category != "Other"), aes(label = Gene, color = Category), size = 3, show.legend = FALSE, max.overlaps = 20) +
    theme_minimal() +
    labs(title = "Connectivity vs. Precedence",
         x = "Connectivity Rank",
         y = "PubMed Rank",
         color = "Legend") +
    theme(
      plot.title = element_text(hjust = 0.5, size = 14, face = "bold"),
      axis.title.x = element_text(size = 12),
      axis.title.y = element_text(size = 12),
      axis.text = element_text(size = 10),
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      axis.ticks = element_line(color = "black"),
      axis.line = element_blank(),
      panel.border = element_rect(color = "black", fill = NA, linewidth = 1)
    )

  if (export && !is.null(file_directory)) {
    rank_scatter_output_filename <- paste(formatted_date, "Connectivity_vs_Precedence.png", sep = "_")
    full_rank_scatter_output_path <- file.path(file_directory, rank_scatter_output_filename)
    png(filename = full_rank_scatter_output_path, width = 1000, height = 800, res = 150)
    print(plot)
    dev.off()
    message("Plot exported and device closed.")
  } else {
    print(plot)
  }

  return(invisible(plot))
}

#' @importFrom utils head str
NULL

#' Run DeSciDe pipeline
#'
#' Run the entire analysis pipeline including PubMed search, STRING database search, and plotting.
#'
#' @param genes_list A list of gene IDs.
#' @param terms_list A list of search terms.
#' @param rank_method The method to rank pubmed results, either "weighted" or "total". Weighted ranks results based on order of terms inputted. Total ranks results on total sum of publications across all search term combinations. Defaults to "weighted".
#' @param species The NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).
#' @param network_type The type of string network to use, either "full" or "physical". Defaults to "full".
#' @param score_threshold The minimum score threshold for string interactions. Defaults to 400.
#' @param threshold_percentage Percentage threshold for ranking (default is 20%).
#' @param export Logical indicating whether to export the results. Defaults to FALSE.
#' @param file_directory Directory for saving the output files. Defaults to NULL.
#' @param export_format Format for export, either "csv", "tsv", or "excel".
#' @return A list containing the PubMed search results, STRING results, and summary results.
#' @examples
#' \donttest{
#' genes <- c("TP53", "BRCA1")
#' terms <- c("cancer", "tumor")
#' results <- descide(genes, terms, export = FALSE)
#' str(results)
#' }
#' @export
descide <- function(genes_list, terms_list,
                    rank_method = "weighted",
                    species = 9606,
                    network_type = "full",
                    score_threshold = 400,
                    threshold_percentage = 20,
                    export = FALSE,
                    file_directory = NULL,
                    export_format = "csv") {

  log_message <- function(message) {
    message(paste0(Sys.time(), ": ", message))
  }

  log_message("Starting analysis pipeline")

  current_date <- Sys.Date()
  formatted_date <- format(current_date, "%m.%d.%Y")

  if (export && is.null(file_directory)) {
    stop("Export is set to TRUE, but file_directory is not provided.")
  }

  # Step 1: Perform PubMed search
  log_message("Performing PubMed search")
  pubmed_search_results <- search_pubmed(genes_list, terms_list, rank_method)

  log_message("PubMed search completed. Results:")
  message(head(pubmed_search_results))

  # Step 2: Plot heatmap of PubMed search results
  log_message("Plotting heatmap of PubMed search results")
  plot_heatmap(pubmed_search_results, file_directory, export)

  # Step 3: Perform STRING database search
  log_message("Performing STRING database search")
  string_db_results <- search_string_db(genes_list, species, network_type, score_threshold)

  string_results <- string_db_results$string_results
  string_db <- string_db_results$string_db
  string_ids <- string_db_results$string_ids

  log_message("STRING database search completed. Results:")
  message(head(string_results))

  # Step 4: Plot STRING network interactions
  log_message("Plotting STRING network interactions")
  plot_string_network(string_db, string_ids, file_directory, export)

  # Step 5: Combine PubMed and STRING summaries
  log_message("Combining summaries")
  combined_summary <- combine_summary(pubmed_search_results, string_results, file_directory, export_format, export, threshold_percentage)

  # Step 6: Plot degree vs. clustering coefficient
  log_message("Plotting clustering coefficient")
  plot_clustering(string_results, file_directory, export)

  # Step 7: Categorize and plot genes
  log_message("Categorizing and plotting genes")
  plot_connectivity_precedence(combined_summary, file_directory, export)

  log_message("FINISHED: Analysis pipeline completed")

  combined_summary_filename <- paste(formatted_date, "Combined_Summary", sep = "_")
  combined_summary_filename <- switch(
    export_format,
    "csv" = paste0(combined_summary_filename, ".csv"),
    "tsv" = paste0(combined_summary_filename, ".tsv"),
    "excel" = paste0(combined_summary_filename, ".xlsx")
  )

  full_combined_summary_path <- if (export) file.path(file_directory, combined_summary_filename) else NULL

  return(list(
    pubmed_results = pubmed_search_results,
    string_results = string_results,
    summary_results = if (export) full_combined_summary_path else combined_summary
  ))
}

library(testthat)
library(DeSciDe)
library(withr)

test_that("descide function exports correctly", {
  skip_on_cran()  # Skipping this test on CRAN

  genes_list <- c("JUN", "MYC", "HDAC1", "TRIM33")
  terms_list <- c("cancer", "romidepsin")
  current_date <- format(Sys.Date(), "%m.%d.%Y")

  tmp_dir <- local_tempdir()

  # Capture messages and warnings to check function execution
  f_capture_output <- capture.output({
    results <- suppressWarnings({
      descide(
        genes_list = genes_list,
        terms_list = terms_list,
        export = TRUE,
        file_directory = tmp_dir,
        export_format = "csv"
      )
    })
  }, type = "message")

  # Check if the exported summary file exists
  expected_summary_file <- paste0(current_date, "_Combined_Summary.csv")
  expect_true(file.exists(file.path(tmp_dir, expected_summary_file)))

  # Check if the heatmap image exists
  expected_heatmap_file <- paste0(current_date, "_PubMed_Heatmap.png")
  expect_true(file.exists(file.path(tmp_dir, expected_heatmap_file)))

  # Check if the STRINGdb network image exists
  expected_string_network_file <- paste0(current_date, "_STRINGdb_Network.pdf")
  expect_true(file.exists(file.path(tmp_dir, expected_string_network_file)))

  # Check if the Degree vs Clustering Coefficient plot exists
  expected_clustering_plot_file <- paste0(current_date, "_Degree_vs_ClusteringCoefficient.png")
  expect_true(file.exists(file.path(tmp_dir, expected_clustering_plot_file)))

  # Check if the Connectivity vs Precedence plot exists
  expected_precedence_plot_file <- paste0(current_date, "_Connectivity_vs_Precedence.png")
  expect_true(file.exists(file.path(tmp_dir, expected_precedence_plot_file)))

  # Repeat the above tests for TSV and Excel export formats

  tmp_dir <- local_tempdir()

  # Capture messages and warnings to check function execution
  f_capture_output <- capture.output({
    results <- suppressWarnings({
      descide(
        genes_list = genes_list,
        terms_list = terms_list,
        export = TRUE,
        file_directory = tmp_dir,
        export_format = "tsv"
      )
    })
  }, type = "message")

  expected_summary_file <- paste0(current_date, "_Combined_Summary.tsv")
  expect_true(file.exists(file.path(tmp_dir, expected_summary_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_heatmap_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_string_network_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_clustering_plot_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_precedence_plot_file)))

  tmp_dir <- local_tempdir()

  # Capture messages and warnings to check function execution
  f_capture_output <- capture.output({
    results <- suppressWarnings({
      descide(
        genes_list = genes_list,
        terms_list = terms_list,
        export = TRUE,
        file_directory = tmp_dir,
        export_format = "excel"
      )
    })
  }, type = "message")

  expected_summary_file <- paste0(current_date, "_Combined_Summary.xlsx")
  expect_true(file.exists(file.path(tmp_dir, expected_summary_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_heatmap_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_string_network_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_clustering_plot_file)))
  expect_true(file.exists(file.path(tmp_dir, expected_precedence_plot_file)))
})

---
title: "DeSciDe Vignette"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{DeSciDe Vignette}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 8,
  fig.height = 6
)
```

```{r setup, include = FALSE}
library(DeSciDe)

# Define evaluation flag
eval_flag <- Sys.getenv("NOT_CRAN") == "TRUE"

# Load precomputed results if not in CRAN
if(!eval_flag) {
  load("data/results_default.RData")
  load("data/results_total.RData")
  load("data/threshold_50.RData")
  load("data/threshold_20.RData")
}
```

# DeSciDe (Deciphering Scientific Discoveries)

DeSciDe is a package designed to help streamline omics data analysis. Many methods of data analysis exist for the generation and characterization of gene lists, however, selection of genes for further investigation is still heavily influenced by prior knowledge, with practitioners often studying well characterized genes, reinforcing bias in the literature. This package aims to aid in the identification of both well-studied, high-confidence hits as well as novel hits that may be overlooked due to lack of prior literature precedence.

This package takes a curated list of genes from a user's omics dataset and a list of cellular stimuli or cellular contexts pertaining to the experiment at hand. The list of genes is searched in the STRING database, and informative metrics are calculated and used to rank the gene list by network connectivity. Then the genes list and terms list are searched for co-occurrence of each gene and search term combination to identify the literature precedence of each gene in the context of the search terms provided. The PubMed results are then used to rank the genes list by number of publications associated with the search terms.

The two ranks for each gene are then plotted on a scatter plot to visualize the relationship of the genes' literature precedence and network connectivity. This visual aid can be used to identify highly connected, well-studied genes that serve as high confidence hits clustered around the origin and highly connected, low precedence genes that serve as novel hits clustered in the top left of the graph. The highly connected, low precedence genes are known to interact with the other genes in the list, but have not been studied in the same experimental context, providing novel targets to pursue for follow up studies.

Additional graphical outputs are generated to visualize the STRING network and PubMed results. The package is designed for flexibility, allowing users to customize various steps of the analysis to fit their specific needs. Users can search STRING for all connections or just physical interactions, adjust the threshold for gene classification, and export figures and data tables for use in publications.

We encourage users to be mindful of several limitations of the platform. DeSciDe is intended to help narrow down large omics datasets to guide subsequent experimental investigations, but it does not definitively determine any biological function. Successful use of the platform relies on inputting high-quality gene lists that have undergone appropriate quality control and statistical analysis for the omics platform used. We recommend using datasets of more than 20 and fewer than 500 genes to achieve optimal results.

Below, we provide an example of how to implement DeSciDe in studying an example dataset.

## Example Usage of DeSciDe

For the following examples we will use a list of 40 genes and 3 search terms. We will call these lists "genes" and "terms". Here we import the lists from CSV files, however the user can choose to manually create these lists or import how they see best fit.

```{r, error=FALSE}
# Import genes list and terms list from CSV
genes <- read.csv("genes.csv", header = FALSE)[[1]]
terms <- read.csv("terms.csv", header = FALSE)[[1]]
```

We now have a list of our genes and terms to execute in our code:

```{r}
genes
```

```{r}
terms
```

We can now run DeSciDe on this list in the most simple form. This will produce our figures and our data table of results.

```{r plot_chunk, message=FALSE, warning=FALSE, eval = eval_flag}
results <- descide(genes_list = genes, terms_list = terms)
```

### Results Expected from DeSciDe

```{r, include = FALSE, eval=!eval_flag}
# Load precomputed results
results <- results_default
```
##### Table
```{r, fig.width=8, fig.height=6, echo = FALSE}
head(results$summary_results)
```

##### Heatmap
```{r, fig.width=8, fig.height=6, echo = FALSE}
plot_heatmap(results$pubmed_results)
```

##### STRING Network
```{r, fig.width=8, fig.height=6, echo = FALSE}
knitr::include_graphics("data/Network_full.pdf")
```

##### Clustering
```{r, fig.width=8, fig.height=6, echo = FALSE}
plot_clustering(results$string_results)
```

##### Connectivity vs. Precedence
```{r, fig.width=8, fig.height=6, echo = FALSE}
plot_connectivity_precedence(results$summary_results)
```

## Modifications to DeSciDe Search

### [PubMed Ranking Method: Important]{.underline}

By default, the PubMed search results are sorted for ranking in order of the terms provided. Here we gave "Acidic Patch " first, so the table is sorted with preference for "Acidic Patch" and then sorted by "Chromatin" and finally by "Nucleosome". You can see that this results in CHD4 being ranked as lower precedence that SUV420H1 even though it has more publications in both the chromatin and nucleosome searches. You must be aware of this when creating your search term list. This weighting has been incorporated to help users emphasize terms highly specific to their research that may have significantly lower number of results than a broader term incorporated into the search (i.e. Chromatin in our search).

If a user does not want to weight their search to a specific term, they can use the argument `rank_method = "total"` to rank the genes by the sum of publication numbers across each search term.

```{r message=FALSE, fig.width=8, fig.height=6, eval = eval_flag}
results_total <- descide(genes_list = genes, terms_list = terms, rank_method = "total")
```

```{r, include = FALSE, eval=!eval_flag}
# Load precomputed results for rank_method = "total"
results_total <- results_total
```

Observe the changes in the PubMed rankings and the Heatmap as a result of weighting by "total". SUV420H1 is dropped from rank 2 down to 13 as a result of the change in weighting. It is important for users to be aware of the differences in these two methods. Both methods, weighted or total, can provide valuable insight into a data set, but the user needs to be conscientious of which method is going to best serve their purpose.

```{r}
head(results$summary_results)
```

```{r}
head(results_total$summary_results)
```

The more specific and niche the search terms are, the more likely you will want to use weighted. In the example here, "Acidic Patch" is a specific term that does not appear in many publications in combination with the provided gene list. The experiment associated with this dataset was studying mutations to the acidic patch of histone H2A, so as a primary variable in the experiment it is valuable to weight the results to this term, to ensure that the variables of the system (WT or mutants of histone H2A acidic patch) would be represented in DeSciDe's results. Searching by total, however, can provide a good starting place for analysis when a user is not sure what terms to prioritize or does not yet know what precedence there is among their gene list for the terms they include.

The user should be aware that DeSciDe conducts a stringent PubMed search, so the number of publications that are reported using DeSciDe will vary from a default search conducted on the PubMed web interface. Here, we have restricted the search to publication titles and abstracts, which avoids potential false positives from author lists, journal titles, and metadata. We have also limited the search to articles in which only the combination of both the search term and the gene name are found in the title or abstract, eliminating articles that only contain either the search term or the gene name. Last, the PubMed search is strictly limited to the explicit terms provided, so the stemming and related terms that are included in the default PubMed search are excluded. 

### [Modifications to STRING Search]{.underline}

When searching the STRING database for gene interactions, there are a variety of variables that can be adjusted. These variable modifications have been included in DeSciDe's usage. First is the specification of the species of interest. The package defaults to search for human genes, but this can be changed by the user with argument `species =` as shown below:\

```{r, eval=FALSE, fig.width=8, fig.height=6}
# Change species to mus musculus for STRING search.
descide(genes_list = genes, terms_list = terms, species = 10090)
```

Additionally, STRING creates scores for each interaction that occurs within a network. This score can be adjusted to increase or decrease the confidence in interactions. High confidence interactions have a score of 1000 and low confidence interactions have a score of 0. The default score for STRING is 400, which is the default used within DeSciDe. To change the STRING score minimum value, the user can use the argument `score_threshold =`:

```{r, eval=FALSE, fig.width=8, fig.height=6}
# Change STRING score threshold to 600.
descide(genes_list = genes, terms_list = terms, score_threshold = 600)
```

The last variable that can be changed within DeSciDe to modify the STRING search is modifying the network type. By default DeSciDe uses a full network search. The full network includes all functional relationships between genes/proteins whether they directly interact or are related to each other for other reasons such as homology, gene ontology, etc. The other option is to limit the network to explicitly physical interactions. This parameter can be changed within DeSciDe by using the argument `network_type =`:

```{r, eval=FALSE, fig.width=8, fig.height=6}
# Change STRING network type to only include physical interactions.
descide(genes_list = genes, terms_list = terms, network_type = "physical")
```

We can run just the STRING search to see the differences in the network produced by using full or physical network. With the full network, we see many more interactions between genes:

```{r full_string_chunk, warning=FALSE, fig.width=8, fig.height=6, eval = eval_flag}
# Run STRING search and display network with full network.
full_string <- search_string_db(genes_list = genes, network_type = "full")
plot_string_network(full_string$string_db, full_string$string_ids)
```

```{r, warning=FALSE, fig.width=8, fig.height=6, echo=FALSE, eval=!eval_flag}
knitr::include_graphics("data/Network_full.pdf")
```

With the more stringent physical network, we see fewer interactions.

```{r physical_string_chunk, warning=FALSE, fig.width=8, fig.height=6, eval = eval_flag}
# Run STRING search and display network with physical network.
physical_string <- search_string_db(genes_list = genes, network_type = "physical")
plot_string_network(physical_string$string_db, physical_string$string_ids)
```

```{r, warning=FALSE, fig.width=8, fig.height=6, echo=FALSE, eval=!eval_flag}
knitr::include_graphics("data/Network_physical.pdf")
```

### [Modifications to DeSciDe Classifications]{.underline}

The rank list of PubMed and STRING results are combined into a summary file. These ranks are then used to classify the genes as either high connectivity - high precedence (high confidence genes) or high connectivity - low precedence (novel genes). The classification is conducted by setting thresholds based on the length of the gene list. The default threshold is 20%. High connectivity - high precedence genes are those that fall in the 20th percentile of both pubmed and string ranks (i.e. for a list of 100 genes, these are genes ranked 1-20). High connectivity - low precedence genes are those that rank in the 20th percentile for STRING rank and the 80-100th percentile for PubMed results (i.e. ranks 81-100 in a list of 100 genes). This value can be adjusted by the user to make the classification more or less stringent by using the argument `threshold_percentage =`.

To change the threshold percentage in the complete DeSciDe pipeline:

```{r, eval=FALSE, fig.width=8, fig.height=6}
# Command to adjust threshold_percentage for full descide pipeline.
results <- descide(genes_list = genes, terms_list = terms, threshold_percentage = 50)
```

We can compare the 20% and 50% threshold results by running just the `combine_summary()` and `plot_connectivity_precedence()` functions:

```{r, fig.width=8, fig.height=6}
# Calculate and plot threshold of 20%.
threshold_20 <- combine_summary(pubmed_search_results = results$pubmed_results, string_results = results$string_results, threshold_percentage = 20)
plot_connectivity_precedence(combined_summary = threshold_20)
```

```{r, fig.width=8, fig.height=6, include=FALSE, eval=!eval_flag}
# Load precomputed results for threshold 20%
threshold_20 <- threshold_20
plot_connectivity_precedence(combined_summary = threshold_20)
```

```{r, fig.width=8, fig.height=6}
# Calculate and plot threshold of 50%.
threshold_50 <- combine_summary(pubmed_search_results = results$pubmed_results, string_results = results$string_results, threshold_percentage = 50)
plot_connectivity_precedence(combined_summary = threshold_50)
```

```{r, fig.width=8, fig.height=6, include=FALSE, eval=!eval_flag}
# Load precomputed results for threshold 50%
threshold_50 <- threshold_50
plot_connectivity_precedence(combined_summary = threshold_50)
```

```{r}
head(threshold_20)
head(threshold_50)
```

This change to threshold percentage just modifies the annotation of genes in the category column of the summary results and the annotations of the genes on the scatter plot of connectivity vs precedence. Using higher threshold can help get a better visual idea of where more genes fall in the analysis, but lowering the threshold can help narrow in on select genes to conduct follow up experiments on.

### [Exporting Tables and Graphs]{.underline}

For ease of use, we have incorporated a feature to easily export all of the tables and graphs to the users desired destination. To do this, you can use the arguments `export = TRUE` and `file_directory = "your/desired/directory"` to export to your desired directory. Furthermore, you can specify the format of the tables using `export_format =`, which you can specify as "csv", "tsv", or "excel". Here is an example of running the full DeSciDe pipeline to be exported:\
\

```{r, eval=FALSE,fig.width=8, fig.height=6}
# Code to run DeSciDe and export all plots and tables to desired directory.
descide(genes_list = genes, terms_list = terms, export = TRUE, file_directory = "your/desired/directory", export_format = "excel")
```

## All Functions Available for DeSciDe

Each step of DeSciDe can be run individually if you wish to do so. Below we briefly list each function and all of their arguments. To see more information, you can use the help function in R studio to see the R documentation for each function (i.e. `?descide` or `?plot_connectivity_precedence`)

### Function to run entire pipeline

```{r, eval=FALSE}
descide(
  genes_list,
  terms_list,
  rank_method = "weighted",
  species = 9606,
  network_type = "full",
  score_threshold = 400,
  threshold_percentage = 20,
  export = FALSE,
  file_directory = NULL,
  export_format = "csv"
)
```

### Function to run PubMed search

```{r, eval=FALSE}
search_pubmed(genes_list, terms_list, rank_method = "weighted")
```

### Function to plot heatmap

```{r, eval=FALSE}
plot_heatmap(pubmed_search_results, file_directory = NULL, export = FALSE)
```

### Function to search STRING

```{r, eval=FALSE}
search_string_db(
  genes_list,
  species = 9606,
  network_type = "full",
  score_threshold = 400
)
```

### Function to plot STRING network

```{r, eval=FALSE}
plot_string_network(
  string_db,
  string_ids,
  file_directory = NULL,
  export = FALSE
)
```

### Function to plot STRING clustering metrics

```{r, eval=FALSE}
plot_clustering(string_results, file_directory = NULL, export = FALSE)
```

### Function to create summary file and classify genes based on ranks.

```{r, eval=FALSE}
combine_summary(
  pubmed_search_results,
  string_results,
  file_directory = NULL,
  export_format = "csv",
  export = FALSE,
  threshold_percentage = 20
)
```

### Function to plot connectivity vs. precedence.

```{r, eval=FALSE}
plot_connectivity_precedence(
  combined_summary,
  file_directory = NULL,
  export = FALSE
)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pubmed_functions.R
\name{search_pubmed}
\alias{search_pubmed}
\title{Search PubMed with Multiple Genes and Terms}
\usage{
search_pubmed(genes_list, terms_list, rank_method = "weighted", verbose = TRUE)
}
\arguments{
\item{genes_list}{A list of gene IDs.}

\item{terms_list}{A list of search terms.}

\item{rank_method}{The method to rank results, either "weighted" or "total". Defaults to "weighted".}

\item{verbose}{Logical flag indicating whether to display messages. Default is TRUE.}
}
\value{
A data frame with search results, including genes, terms, and their corresponding publication counts and ranks.
}
\description{
Perform a PubMed search for multiple genes and terms.
}
\examples{
genes <- c("TP53", "BRCA1")
terms <- c("cancer", "tumor")
search_results <- search_pubmed(genes, terms, rank_method = "weighted", verbose = FALSE)
print(search_results)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/descide_master_functions.R
\name{descide}
\alias{descide}
\title{Run DeSciDe pipeline}
\usage{
descide(
  genes_list,
  terms_list,
  rank_method = "weighted",
  species = 9606,
  network_type = "full",
  score_threshold = 400,
  threshold_percentage = 20,
  export = FALSE,
  file_directory = NULL,
  export_format = "csv"
)
}
\arguments{
\item{genes_list}{A list of gene IDs.}

\item{terms_list}{A list of search terms.}

\item{rank_method}{The method to rank pubmed results, either "weighted" or "total". Weighted ranks results based on order of terms inputted. Total ranks results on total sum of publications across all search term combinations. Defaults to "weighted".}

\item{species}{The NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).}

\item{network_type}{The type of string network to use, either "full" or "physical". Defaults to "full".}

\item{score_threshold}{The minimum score threshold for string interactions. Defaults to 400.}

\item{threshold_percentage}{Percentage threshold for ranking (default is 20\%).}

\item{export}{Logical indicating whether to export the results. Defaults to FALSE.}

\item{file_directory}{Directory for saving the output files. Defaults to NULL.}

\item{export_format}{Format for export, either "csv", "tsv", or "excel".}
}
\value{
A list containing the PubMed search results, STRING results, and summary results.
}
\description{
Run the entire analysis pipeline including PubMed search, STRING database search, and plotting.
}
\examples{
\donttest{
genes <- c("TP53", "BRCA1")
terms <- c("cancer", "tumor")
results <- descide(genes, terms, export = FALSE)
str(results)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_and_plot_functions.R
\name{plot_connectivity_precedence}
\alias{plot_connectivity_precedence}
\title{Plot Connectivity vs. Precedence}
\usage{
plot_connectivity_precedence(
  combined_summary,
  file_directory = NULL,
  export = FALSE
)
}
\arguments{
\item{combined_summary}{Data frame with combined summary including categories.}

\item{file_directory}{Directory for saving the output plot. Defaults to NULL.}

\item{export}{Logical indicating whether to export the plot. Defaults to FALSE.}
}
\value{
Invisibly returns a ggplot object.
}
\description{
Create a scatter plot of Connectivity Rank vs. PubMed Rank.
}
\examples{
combined_data <- data.frame(Gene = c("Gene1", "Gene2"), Connectivity_Rank = c(1, 2),
                            PubMed_Rank = c(2, 1),
                            Category = c("High Connectivity - High Precedence", "Other"))
plot_connectivity_precedence(combined_data, export = FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stringdb_functions.R
\name{search_string_db}
\alias{search_string_db}
\title{Search STRING Database}
\usage{
search_string_db(
  genes_list,
  species = 9606,
  network_type = "full",
  score_threshold = 400
)
}
\arguments{
\item{genes_list}{A list of gene IDs.}

\item{species}{The NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).}

\item{network_type}{The type of network to use, either "full" or "physical". Defaults to "full".}

\item{score_threshold}{The minimum score threshold for string interactions. Defaults to 400.}
}
\value{
A list containing the following elements:
\describe{
\item{string_results}{A data frame with STRING interaction metrics.}
\item{string_db}{The STRINGdb object used.}
\item{string_ids}{The STRING IDs for the input genes.}
}
}
\description{
Search the STRING database for protein interactions.
}
\examples{
\dontrun{
library(STRINGdb)
genes <- c("TP53", "BRCA1")
results <- search_string_db(genes)
print(results)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_and_plot_functions.R
\name{combine_summary}
\alias{combine_summary}
\title{Combine PubMed and STRING Metrics}
\usage{
combine_summary(
  pubmed_search_results,
  string_results,
  file_directory = NULL,
  export_format = "csv",
  export = FALSE,
  threshold_percentage = 20
)
}
\arguments{
\item{pubmed_search_results}{Data frame with PubMed search results.}

\item{string_results}{Data frame with STRING metrics.}

\item{file_directory}{Directory for saving the output summary. Defaults to NULL.}

\item{export_format}{Format for export, either "csv", "tsv", or "excel".}

\item{export}{Logical indicating whether to export the summary. Defaults to FALSE.}

\item{threshold_percentage}{Percentage threshold for ranking (default is 20\%).}
}
\value{
A data frame with combined summary including connectivity, precedence, and category.
}
\description{
Combine PubMed search summary and STRING gene metrics.
}
\examples{
pubmed_data <- data.frame(Gene = c("Gene1", "Gene2"), PubMed_Rank = c(1, 2))
string_data <- data.frame(Gene = c("Gene1", "Gene2"), Connectivity_Rank = c(2, 1))
combined <- combine_summary(pubmed_data, string_data, export = FALSE)
print(combined)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stringdb_functions.R
\name{plot_clustering}
\alias{plot_clustering}
\title{Plot STRING Interactions}
\usage{
plot_clustering(string_results, file_directory = NULL, export = FALSE)
}
\arguments{
\item{string_results}{Data frame with STRING metrics.}

\item{file_directory}{Directory for saving the output plot. Defaults to NULL.}

\item{export}{Logical indicating whether to export the plot. Defaults to FALSE.}
}
\value{
Invisibly returns the ggplot object.
}
\description{
Plot STRING interactions degree vs. clustering.
}
\examples{
# Example data frame
string_results <- data.frame(Degree = c(10, 5), Clustering_Coefficient_Percent = c(20, 10))
plot_clustering(string_results, file_directory = tempdir(), export = FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pubmed_functions.R
\name{single_pubmed_search}
\alias{single_pubmed_search}
\title{Search PubMed}
\usage{
single_pubmed_search(gene, term)
}
\arguments{
\item{gene}{A character string representing the gene symbol.}

\item{term}{A character string representing the search term.}
}
\value{
An integer representing the number of PubMed articles found from the search query in PubMed.
}
\description{
Perform a PubMed search for a given gene and term.
}
\examples{
# Perform a PubMed search for gene 'TP53' with term 'cancer'
result <- single_pubmed_search("TP53", "cancer")
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmap_functions.R
\name{plot_heatmap}
\alias{plot_heatmap}
\title{Plot Heatmap}
\usage{
plot_heatmap(pubmed_search_results, file_directory = NULL, export = FALSE)
}
\arguments{
\item{pubmed_search_results}{A data frame containing raw search results with genes and terms.}

\item{file_directory}{Directory for saving the output plot. Defaults to NULL.}

\item{export}{Logical indicating whether to export the plot. Defaults to FALSE.}
}
\value{
Invisibly returns a \code{HeatmapList} object.
}
\description{
Create and optionally save a heatmap of the PubMed search results.
}
\examples{
# Example data frame
data <- data.frame(Gene = c("Gene1", "Gene2"),
                   Term1 = c(10, 20),
                   Term2 = c(5, 15),
                   Total = c(15, 35),
                   PubMed_Rank = c(1, 2))
plot_heatmap(data, file_directory = tempdir(), export = FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pubmed_functions.R
\name{rank_search_results}
\alias{rank_search_results}
\title{Rank Search Results}
\usage{
rank_search_results(data, terms_list, rank_method = "weighted")
}
\arguments{
\item{data}{A data frame containing search results.}

\item{terms_list}{A list of search terms.}

\item{rank_method}{The method to rank pubmed results, either "weighted" or "total". Weighted ranks results based on order of terms inputted. Total ranks results on total sum of publications across all search term combinations. Defaults to "weighted".}
}
\value{
A data frame with ranked search results, which includes the genes and their corresponding ranks based on the search method.
}
\description{
Rank search results based on a chosen method.
}
\examples{
# Example data frame
data <- data.frame(Gene = c("Gene1", "Gene2"),
                   Term1 = c(10, 20),
                   Term2 = c(5, 15))
terms_list <- c("Term1", "Term2")
ranked_results <- rank_search_results(data, terms_list, rank_method = "weighted")
print(ranked_results)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stringdb_functions.R
\name{plot_string_network}
\alias{plot_string_network}
\title{Plot STRING Network}
\usage{
plot_string_network(
  string_db,
  string_ids,
  file_directory = NULL,
  export = FALSE
)
}
\arguments{
\item{string_db}{A STRINGdb object.}

\item{string_ids}{A list of STRING IDs.}

\item{file_directory}{Directory for saving the output plot. Defaults to NULL.}

\item{export}{Logical indicating whether to export the plot. Defaults to FALSE.}
}
\value{
Invisibly returns NULL.
}
\description{
Plot STRING network interactions using STRINGdb.
}
\examples{
\dontrun{
library(STRINGdb)
string_db <- STRINGdb$new(species = 9606)
string_ids <- c("9606.ENSP00000269305", "9606.ENSP00000357940")
plot_string_network(string_db, string_ids, file_directory = tempdir(), export = FALSE)
}
}
